﻿
namespace TDD.Mocking
{
    // Starting point before refactoring: hard-coded dependency on concrete class 
    // Cf. Osherove, section 3.4 "Refactoring our design to be more testable"
    // 1. Receive an interface at the constructor level and save it in a field for later use
    // = OrderReader
    // NB the two constructors can be combined in a single class
    // No args (OrderReader0) - default constructor creates object
    // 1 arg (OrderReader) - receives interface; constructor can be called by tests
    // Can put the 1 arg in a conditional compliation region so not visible in release mode
    // #if DEBUG ... #endif
    // Alternatively annotate with the attribute [Conditional("DEBUG")]
    // Or make constructor internal rather than public 
    class OrderReader0
    {
        private FileReader _fileReader;
        public OrderReader0()
        {
            _fileReader = new FileReader();
        }

        public Order ReadOrder()
        {
            _fileReader.FileName = "record.csv";
            string line = _fileReader.ReadLine();
            _fileReader.Close();
            string[] details = line.Split(new char[] { ',' });
            int id = int.Parse(details[0]);
            string cust = details[1];
            double price = double.Parse(details[2]);
            Order order = new Order(id, cust, price);
            return order;
        }

    }
}
