﻿
namespace TDD.Mocking
{
    // Osherove, section 3.4 "Refactoring our design to be more testable"
    // 3. Receive an interface before the method call - b) use a local factory method
    // i.e. get an instance of an object just before you do any operations with it
    // "Extract & override"
    // variant on the factory class approach, but even simpler 
    public class OrderReader3
    {
        // local virtual factory method 
        protected virtual IFileReader GetReader()
        {
            return new FileReader(); 
        }

        public Order ReadOrder()
        {
            IFileReader fileReader = GetReader(); 
            fileReader.FileName = "record.csv";
            string line = fileReader.ReadLine();
            fileReader.Close();
            string[] details = line.Split(new char[] { ',' });
            int id = int.Parse(details[0]);
            string cust = details[1];
            double price = double.Parse(details[2]);
            Order order = new Order(id, cust, price);
            return order;
        }
    }
}
