﻿using NUnit.Framework;
using Moq;

namespace TDD.Mocking
{
    [TestFixture]
    class OrderReader2MoqTest
    {
        OrderReader2 orderReader;
        private Mock<IFileReader> mockFileReader;

        [SetUp]
        public void SetUp()
        {
            mockFileReader = new Mock<IFileReader>();
            // Set the mock to be the factory's FileReader
            FileReaderFactory.SetReader(mockFileReader.Object);
            orderReader = new OrderReader2();
        }

        [Test]
        public void ReadOrder_CreatesOrder()
        {
            mockFileReader.SetupSet(fr => fr.FileName = "record.csv");
            mockFileReader.Setup(fr => fr.ReadLine()).Returns("27412,FUBAR,876543.21").AtMostOnce();
            mockFileReader.Setup(fr => fr.Close());

            Order order = orderReader.ReadOrder();

            mockFileReader.VerifyAll();
            Assert.That(order.OrderId, Is.EqualTo(27412));
            Assert.That(order.Customer, Is.EqualTo("FUBAR"));
            Assert.That(order.Price, Is.EqualTo(876543.21));
        }

    }
}
