﻿using NUnit.Framework;
using Rhino.Mocks;

namespace TDD.Mocking {
    /*
     "Extract and Override is great for simulating inputs into your code under test, but it's 
     cumbersome when you want to verify interactions that are coming out of the code under test
     into your dependency."  Osherove, p. 74.  
     */

    [TestFixture]
    class OrderReader3RhinoTest {
        MockRepository repository;
        IFileReader mockFileReader;
        // Declare instance of auxiliary subclass which is testable
        OrderReader3Aux orderReader;

        [SetUp]
        public void SetUp() {
            repository = new MockRepository();
            mockFileReader = repository.StrictMock<IFileReader>();
            orderReader = new OrderReader3Aux();
            // has a public variable we set directly to the mock object: 
            orderReader.fileReader = mockFileReader;
        }

        [Test]
        public void TestReadOrder0() {
            Expect.Call(mockFileReader.FileName = "record.csv");
            Expect.Call(mockFileReader.ReadLine()).Return("27412,FUBAR,876543.21");
            mockFileReader.Close();
            LastCall.Repeat.Once();
            repository.ReplayAll();

            Order order = orderReader.ReadOrder();
            repository.VerifyAll();

            Assert.That(order.OrderId, Is.EqualTo(27412));
            Assert.That(order.Customer, Is.EqualTo("FUBAR"));
            Assert.That(order.Price, Is.EqualTo(876543.21));
        }

    }
}
