﻿
Namespace TDD.Mocking
    ' Main version of Class Under Test; constructor injection 
    Public Class OrderReader
        Private ReadOnly _fileReader As IFileReader

        Public Sub New(fileReader As IFileReader)
            Me._fileReader = fileReader
        End Sub

        Public Function ReadOrder() As Order
            _fileReader.FileName = "record.csv"
            Dim line As String = _fileReader.ReadLine()
            _fileReader.Close()
            Dim details As String() = line.Split(New Char() {","c})
            Dim id As Integer = Integer.Parse(details(0))
            Dim cust As String = details(1)
            Dim price As Double = Double.Parse(details(2))
            Dim order As New Order(id, cust, price)
            Return order
        End Function
    End Class
    '
    '     One problem with constructor injection: what if there are multiple external dependencies?
    '     Have to add more & more parameters to constructor, or more & more constructor overloads
    '     -> code becomes less readable/maintainable 
    '     Solutions: 1) parameter object refactoring: create a class that contains all the values 
    '     needed, and just pass that single instance to the constructor
    '     2) Inversion of Control containers (Castle Windsor, Spring.NET, Ninjet, StructureMap, etc.) 
    '    

End Namespace
