﻿Imports NUnit.Framework
Imports NUnit.Mocks

Namespace TDD.Mocking
    ' Uses the lightweight mocking API built into NUnit 
    <TestFixture()> _
    Class OrderReaderNUnitTest
        ' Need the DynamicMock instance to Expect & Verify
        Private dynamicMock As DynamicMock
        ' Need it cast to IFileReader for OrderReader
        Private mockFileReader As IFileReader
        Private orderReader As OrderReader

        <SetUp()> _
        Public Sub SetUp()
            dynamicMock = New DynamicMock(GetType(IFileReader))
            mockFileReader = DirectCast(dynamicMock.MockInstance, IFileReader)
            orderReader = New OrderReader(mockFileReader)
        End Sub

        <Test()> _
        Public Sub TestReadOrder()
            ' No special method for expecting property setter, 
            ' so use underlying method for which it is syntactic suger
            dynamicMock.Expect("set_FileName", "record.csv")
            dynamicMock.ExpectAndReturn("ReadLine", "272,ABC,543.21")
            dynamicMock.Expect("Close")

            Dim orderReader As New OrderReader(mockFileReader)
            Dim order As Order = orderReader.ReadOrder()
            dynamicMock.Verify()

            Assert.That(order.OrderId, [Is].EqualTo(272))
            Assert.That(order.Customer, [Is].EqualTo("ABC"))
            Assert.That(order.Price, [Is].EqualTo(543.21))
        End Sub
    End Class
End Namespace
